package App::Manoc::DB::Result::UserRole;

use strict;
use warnings;

our $VERSION = '2.99.2'; ##TRIAL VERSION

use parent 'App::Manoc::DB::Result';

__PACKAGE__->table('user_roles');
__PACKAGE__->add_columns(
    user_id => {
        data_type      => 'int',
        is_foreign_key => 1,
        is_nullable    => 0,
    },
    role_id => {
        data_type      => 'int',
        is_foreign_key => 1,
        is_nullable    => 0,
    }
);

__PACKAGE__->set_primary_key(qw/user_id role_id/);

__PACKAGE__->belongs_to( user => 'App::Manoc::DB::Result::User', 'user_id' );
__PACKAGE__->belongs_to( role => 'App::Manoc::DB::Result::Role', 'role_id' );


1;

__END__

=pod

=head1 NAME

App::Manoc::DB::Result::UserRole

=head1 VERSION

version 2.99.2

=head1 DESCRIPTION

This is an object that represents a row in the 'user_roles' table of your
application database.  It uses DBIx::Class (aka, DBIC) to do ORM.

=head1 NAME

App::Manoc::DB::Result::UserRole - A model object representing the JOIN between Users and
Roles.

=head1 AUTHORS

=over 4

=item *

Gabriele Mambrini <gmambro@cpan.org>

=item *

Enrico Liguori

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Gabriele Mambrini.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
