package App::Manoc::DB::ResultSet::ServerHW;
#ABSTRACT: ResultSet class for ServerHW

use strict;
use warnings;

our $VERSION = '2.99.2'; ##TRIAL VERSION

use parent 'App::Manoc::DB::ResultSet';

use App::Manoc::DB::Result::HWAsset;


sub unused {
    my ($self) = @_;

    my $used_asset_ids = $self->result_source->schema->resultset('Server')->search(
        {
            'subquery.decommissioned' => 0,
            'subquery.serverhw_id'    => { -is_not => undef }
        },
        {
            alias => 'subquery',
        }
    )->get_column('serverhw_id');

    my $me = $self->current_source_alias;
    my $rs = $self->search(
        {
            'hwasset.location' =>
                { '!=' => App::Manoc::DB::Result::HWAsset::LOCATION_DECOMMISSIONED },
            "$me.id" => {
                -not_in => $used_asset_ids->as_query,
            }
        },
        {
            join => 'hwasset',
        }
    );
    return wantarray ? $rs->all : $rs;

}


1;
# Local Variables:
# mode: cperl
# indent-tabs-mode: nil
# cperl-indent-level: 4
# cperl-indent-parens-as-block: t
# End:

__END__

=pod

=head1 NAME

App::Manoc::DB::ResultSet::ServerHW - ResultSet class for ServerHW

=head1 VERSION

version 2.99.2

=head1 METHODS

=head2 unused

Resultset containing ServerHW which are not decommissioned and
are used by any Server.

=head1 SEE ALSO

L<DBIx::Class::ResultSet>

=head1 AUTHORS

=over 4

=item *

Gabriele Mambrini <gmambro@cpan.org>

=item *

Enrico Liguori

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Gabriele Mambrini.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
